@@ -30,7 +30,7 @@ def weights_shift(weight_mat=None, trading_delay = 1):
     weight_mat = weight_mat.shift(trading_delay)
     return weight_mat, last_predicted_weights
 
-def process_weights(w=None, df=None, s=None, n=None, low_bound=None, up_bound=None, weight_cutting_rate = 0.7, normalize = True , display=False, max_iteration = 50, trading_delay=1):
+def process_weights(w=None, df=None, s=None, n=None, low_bound=None, up_bound=None, weight_cutting_rate = 0.7, normalize = True , display=False, max_iteration = 50, trading_delay=1, display_slices = True):
     """ Process weight to respect constraints.
     Parameters
     ----------
@@ -61,6 +61,9 @@ def process_weights(w=None, df=None, s=None, n=None, low_bound=None, up_bound=No
         # check if the past data are constant
         # if asset i is constant set w_i = 0
         test_slice = slice(t,t_s)
+        if display_slices:
+            print('test slice')
+            print(test_slice)
         len_test_slice = test_slice.stop - test_slice.start
         sub_X = df.iloc[test_slice, :].copy()
         assets = sub_X.apply(cut_process).values
